@@ -27,12 +27,13 @@
 #include <QStandardPaths>
 
 #include <cmath>
+#include "auxiliary/kspaths.h"
 
 namespace KSUtils {
 
 
 bool openDataFile( QFile &file, const QString &s ) {
-    QString FileName = QStandardPaths::locate(QStandardPaths::DataLocation, s );
+    QString FileName = KSPaths::locate(QStandardPaths::GenericDataLocation, s );
     if ( !FileName.isNull() ) {
         file.setFileName( FileName );
         return file.open( QIODevice::ReadOnly );
@@ -140,10 +141,14 @@ QString toDirectionString( dms angle ) {
         I18N_NOOP2( "Abbreviated cardinal / intercardinal etc. direction", "WNW"),
         I18N_NOOP2( "Abbreviated cardinal / intercardinal etc. direction", "NW"),
         I18N_NOOP2( "Abbreviated cardinal / intercardinal etc. direction", "NNW"),
-        I18N_NOOP2( "Abbreviated cardinal / intercardinal etc. direction", "N"),
+        I18N_NOOP2( "Unknown cardinal / intercardinal direction", "???")
     };
 
-    int index = (int)( (angle.Degrees() + 11.25) / 22.5); // A number between 0 and 16 (inclusive), 16 meaning the same thing as zero.
+    int index = (int)( (angle.reduce().Degrees() + 11.25) / 22.5); // A number between 0 and 16 (inclusive) is expected
+    if( index < 0 || index > 16 )
+        index = 17; // Something went wrong.
+    else
+        index = ( ( index == 16 ) ? 0 : index );
 
     return i18nc( "Abbreviated cardinal / intercardinal etc. direction", directions[ index ] );
 }
@@ -533,13 +538,19 @@ QString constGenetiveToAbbrev( const QString &genetive_ ) {
   void Logging::UseFile(const QString &filename)
   {
     _filename = filename;
+
+    // Clear file contents
+    QFile file(filename);
+    file.open(QFile::WriteOnly);
+    file.close();
+
     qInstallMessageHandler(File);
   }
 
   void Logging::File(QtMsgType type, const QMessageLogContext &, const QString &msg)
   {
     QFile file(_filename);
-    if(file.open(QFile::WriteOnly | QIODevice::Text | QIODevice::Append))
+    if(file.open(QFile::Append | QIODevice::Text))
     {
       QTextStream stream(&file);
       Write(stream, type, msg);
